@@ -1,29 +1,15 @@
 
 import numpy as np
-import scipy.linalg
-#import scipy as sp
-#import matplotlib as mpl
-#import matplotlib.pylab as plt
 import os
-import sys
 import warnings
 
-
-'''
-TODO
-    save all images to hdf5 file?
-    option to remove plane
-    opposing single quadrant analysis?
-
-'''
-
-
-
-class SegmentedDPC:    
+class SegmentedDPC:
     def __init__(self, ds, path=None, ext='dm3', alpha=1.0, 
                  scan_deg=0.0, fudge=None, method='accurate', 
                  sum_method='pixel', rebin=0):
         '''
+        DEPRECATED in v0.2.4. Use fpd.segmented_dpc.SegmentedDPC instead.
+        
         Differential Phase Contrast (DPC) class for processing 
         4- and 8-segment DPC data.
         
@@ -102,6 +88,11 @@ class SegmentedDPC:
         
         '''
         
+        with warnings.catch_warnings():
+            warnings.simplefilter("always")
+            msg = 'This function is deprecated and marked for removal.Use the similar (but better) `fpd.segmented_dpc.SegmentedDPC class instead.'
+            warnings.warn(msg, DeprecationWarning)
+        
         
         # condition inputs        
         methods = ['accurate', 'fast']
@@ -344,7 +335,8 @@ class SegmentedDPC:
 
             # best-fit linear plane
             A = np.c_[data[:,0], data[:,1], np.ones(data.shape[0])]
-            C, _, _, _ = scipy.linalg.lstsq(A, data[:, 2])    # coefficients
+            from scipy.linalg import lstsq
+            C, _, _, _ = lstsq(A, data[:, 2])    # coefficients
 
             # evaluate it on grid
             Z = C[0]*X + C[1]*Y + C[2]
@@ -371,4 +363,3 @@ class SegmentedDPC:
         self.dpc_betay.data[:], self.dpc_betax.data[:] = self._rot(self.dpc_betay.data, self.dpc_betax.data, scan_deg)
         if self._oct_seg:
             self.mdpc_betay.data[:], self.mdpc_betax.data[:] = self._rot(self.mdpc_betay.data, self.mdpc_betax.data, scan_deg)
-
